/*****************************************************************************
 *
 *  File: BC790101.ddl
 *
 *  Copyright (C) APLISENS S.A. All Rights Reserved 
 *  Authors:        Jacek Szumigaj
 *  Device:         APT-2000ALW 		        
 *  Communication:  HART        
 *  Revision:   1                                         
 *  Date:       2014.09.08 		                        
 *****************************************************************************/
 
/*****************************************************************************
 * The manufacturer line
 ****************************************************************************/
 
MANUFACTURER APLISENS, DEVICE_TYPE _MPT2, DEVICE_REVISION 1, DD_REVISION 2

/*****************************************************************************
 * Include Files
 *****************************************************************************/

#include "macros.h"
#include "methods.h"

/*****************************************************************************
 * Common Tables
 ****************************************************************************/
IMPORT STANDARD _TABLES, DEVICE_REVISION 20, DD_REVISION 4
{
    VARIABLE units_code;
    VARIABLE transfer_function_code;
    VARIABLE material_code;
    VARIABLE alarm_selection_code;
    VARIABLE write_protect_code;
    VARIABLE company_identification_code;
    VARIABLE burst_mode_control_code;
    VARIABLE physical_signaling_codes;
    VARIABLE flag_assignment;
    VARIABLE operating_mode_code;
    VARIABLE analog_output_numbers_code;
    VARIABLE extended_device_status_codes;
    VARIABLE lock_device_codes;
    VARIABLE write_device_variable_codes;
    VARIABLE device_variable_family_codes;
    VARIABLE device_variable_classification_codes;
    VARIABLE trim_point_codes;
    VARIABLE capture_mode_codes;
    VARIABLE physical_layer_type_codes;
    VARIABLE lock_device_status_codes;
    VARIABLE analog_channel_flags;
    VARIABLE process_data_status;
    VARIABLE limit_status;
    VARIABLE device_family_status;
    VARIABLE manufacturer_id;
    VARIABLE private_label_distributor;
    VARIABLE device_type;
    VARIABLE write_protect;
    VARIABLE physical_signaling_code;
    VARIABLE device_flags;
    VARIABLE analog_channel_saturated1;
    VARIABLE analog_channel_fixed1;
    VARIABLE analog_channel_saturated_codes;
    VARIABLE analog_channel_fixed_codes;

    REDEFINITIONS
    {
        /*
         * The entire variable must be redefined since Device Type is defined as a two-byte 
         * Enumerated and the Tokenizer will not allow the type to be redefined from size 2 to 1.
         */
        REDEFINE VARIABLE device_type
        {
            LABEL [device_type];
            HELP [manufacturers_device_type_help];
            CLASS HART;
            HANDLING READ;
            TYPE ENUMERATED
            {
                // Replace the 0xf9 with your one-byte Device Type code and appropriate label
                { 0x79,  "APT-2000ALW" }
            }
        }

        /*
         * The entire variable must be redefined since Manufacturer ID is defined as a two-byte
         * Enumerated and the Tokenizer will not allow the type to be redefined from size 2 to 1.
         */
        REDEFINE VARIABLE manufacturer_id
        {
            LABEL [manufacturer_id];
            HELP [manufacturer_id_code_help];
            CLASS HART;
            HANDLING READ;
            TYPE ENUMERATED
            {
                // Replace the 0xf9 with your one-byte Manufacturer code and appropriate label
                { 0xbc,  "Aplisens S.A." } 
            }
        }

        /*
         * The entire variable must be redefined since Private Label is defined as a two-byte
         * Enumerated and the Tokenizer will not allow the type to be redefined from size 2 to 1.
         */
        REDEFINE VARIABLE private_label_distributor
        {
            LABEL [private_label_distributor];
            HELP [private_label_distributor_help];
            CLASS DEVICE;
            HANDLING READ;
            TYPE ENUMERATED
            {
                // Replace the 0xf9 with your manufactures id and appropriate label
                { 0xbc,  "Aplisens S.A." } 
            }
        }
    }

}

/*****************************************************************************
 * Universal Commmands
 *****************************************************************************/

IMPORT STANDARD _UNIVERSAL, DEVICE_REVISION 5, DD_REVISION 2
{    
    EVERYTHING;

    REDEFINITIONS
    {
        VARIABLE polling_address 
        {
            REDEFINE LABEL [polling_address];
            REDEFINE HELP [polling_address_help];
            REDEFINE HANDLING WRITE;
            REDEFINE CLASS HART;
            REDEFINE TYPE UNSIGNED_INTEGER
            {
	            MAX_VALUE 15;
            }
            REDEFINE DEFAULT_VALUE  0;
        }

        VARIABLE comm_status
        {
            REDEFINE CLASS LOCAL;
        }
    }
}

 /*****************************************************************************
 *                  PV, when the primary variable
 ******************************************************************************/

IMPORT STANDARD _PV, DEVICE_REVISION 1, DD_REVISION 1
{
    EVERYTHING;

    REDEFINITIONS
    {
        DELETE VARIABLE loop_flags;

        COLLECTION OF VARIABLE analog_io
        {
            MEMBERS
            {
                DELETE ANALOG_CHANNEL_FLAGS;
            } 
        }

        COLLECTION OF VARIABLE scaling
        {
            MEMBERS
            {
                ADD RANGE_UNITS, deviceVariables[0].DIGITAL_UNITS, [range_units], [range_units_help];
            } 
        } 
       
    }
}

/*****************************************************************************
 *                  Common Practice Commands
 *****************************************************************************/
IMPORT STANDARD _COMMON_PRACTICE, DEVICE_REVISION 7, DD_REVISION 4
{
    COMMAND write_pv_damping_value;                 /* command 34 */
    COMMAND write_pv_range_values;                  /* command 35 */
    COMMAND set_pv_upper_range_value;               /* command 36 */
    COMMAND set_pv_lower_range_value;               /* command 37 */ 
    COMMAND reset_configuration_change_flag;        /* command 38 */
    COMMAND enter_exit_fixed_pv_current_mode;       /* command 40 */
    COMMAND perform_device_reset;                   /* command 42 */
    COMMAND set_pv_zero;                            /* command 43 */
    COMMAND write_pv_units;                         /* command 44 */
    COMMAND trim_pv_current_dac_zero;               /* command 45 */
    COMMAND trim_pv_current_dac_gain;               /* command 46 */
    COMMAND write_pv_transfer_function;             /* command 47 */
    COMMAND read_additional_device_status;          /* command 48 */
    COMMAND write_pv_sensor_serial_number;          /* command 49 */
    COMMAND write_number_of_response_preambles;     /* command 59 */
  
    METHOD applied_rerange;
    METHOD zero_trim;
    METHOD return_to_normal;
    METHOD warning_message;
    METHOD device_self_test;
    METHOD device_master_reset;
    METHOD transmitter_loop_test;
    METHOD transmitter_dac_trim;

    VARIABLE device_specific_status_0;
    VARIABLE device_specific_status_1;
    VARIABLE device_specific_status_2;
    VARIABLE device_specific_status_3;
    VARIABLE device_specific_status_4;
    VARIABLE device_specific_status_5;
    VARIABLE device_specific_status_14;
    VARIABLE device_specific_status_15;
    VARIABLE device_specific_status_16;
    VARIABLE device_specific_status_17;
    VARIABLE device_specific_status_18;
    VARIABLE device_specific_status_19;
    VARIABLE device_specific_status_20;
    VARIABLE device_specific_status_21;
    VARIABLE device_specific_status_22;
    VARIABLE device_specific_status_23;
    VARIABLE device_specific_status_24; 
    VARIABLE device_variable_code;

 /***********************************************************
                   REDEFINATIONS
 ************************************************************/                   

    REDEFINITIONS
    {

    VARIABLE write_protect
    {  
      REDEFINE HANDLING READ & WRITE;
      REDEFINE TYPE ENUMERATED
    {
        WRITE_PROTECT_CODE(0),  // NO
        WRITE_PROTECT_CODE(1),   // YES 
        WRITE_PROTECT_CODE(253)  // SPECIAL (MID)
    }     
    }

     VARIABLE response_preambles            
     {  
      REDEFINE HANDLING WRITE;
     }        

     VARIABLE transfer_function
    {
    REDEFINE HANDLING READ & WRITE;
    REDEFINE TYPE ENUMERATED
    {
        TRANSFER_FUNCTION_CODE (0),     // Linear 
        TRANSFER_FUNCTION_CODE (1),     // Sqrt(x) 
        TRANSFER_FUNCTION_CODE (2),     // Sqrt(x^3)
        TRANSFER_FUNCTION_CODE (3),     // Sqrt(x^5)
        TRANSFER_FUNCTION_CODE (4),     // special
        TRANSFER_FUNCTION_CODE (5)      // x^2
    }
    }

    VARIABLE analog_channel_saturated1
    {
        REDEFINE TYPE BIT_ENUMERATED
        {
    		{ 0x01, "Analog Channel 1"},
    		{ 0x02, "Analog Channel 2"},
    		{ 0x04, "Analog Channel 3"},
    		{ 0x08, "Analog Channel 4"}
        }
    }

    VARIABLE analog_channel_fixed1
    {
        REDEFINE TYPE BIT_ENUMERATED
        {
    		{ 0x01, "Analog Channel 1"},
    		{ 0x02, "Analog Channel 2"},
    		{ 0x04, "Analog Channel 3"},
    		{ 0x08, "Analog Channel 4"}
        }
    }

    VARIABLE device_specific_status_1 //error_flags_1
    {
        REDEFINE LABEL "Dev. Spec Status Byte 1"; //"wrd_SSMod_H";
        REDEFINE HELP "ADC, Hart, Osc, Code, Flash flags";
        REDEFINE CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
        REDEFINE TYPE BIT_ENUMERATED
        {                                           
            { 0x01, "RAM Test Error" },
            { 0x02, "Code CRC Error" },
            { 0x04, "Flash CRC Error" },
            { 0x08, "Oscillator Fault" },
            { 0x10, "Hart Modem Error" },
            { 0x20, "ADC Master Error" },
            { 0x40, "ADC Slave Error" },
            { 0x80, "ADC TimeOut" }   
        }
    }


    VARIABLE device_specific_status_0 //error_flags_2
    {
        REDEFINE LABEL "Dev. Spec Status Byte 0"; //"wrd_SSMod_H";
        REDEFINE HELP "PV, SV, Sensor, Analog flags";
        REDEFINE CLASS DEVICE & DIAGNOSTIC & DYNAMIC;
        REDEFINE TYPE BIT_ENUMERATED
        {                                           
            { 0x01, "Sensor Failure" },
            { 0x02, "Sensor Not Connected" },
            { 0x04, "PV Not Valid" },
            { 0x08, "PV Out of Limits" },
            { 0x10, "SV Out of Limits" },
            { 0x20, "Analog Output Saturated" },
            { 0x40, "Output Current Fixed" },
            { 0x80, "Hot Start Occure" }  
        } 
    } 

    COMMAND read_additional_device_status
    {
            REDEFINE TRANSACTION
            {
                REQUEST {}
                REPLY
                {
                    response_code, device_status, 
                    device_specific_status_0 /*error_flags_2*/, device_specific_status_1 /*error_flags_1*/, 
                    device_specific_status_2, device_specific_status_3, 
                    device_specific_status_4, device_specific_status_5, 
                    0x00 /*extended_fld_device_status*/, 0x00 /*operatingMode*/, 
                    0x00 /*analog_channel_saturated3*/, 0x00 /*analog_channel_saturated2*/,  analog_channel_saturated1,
                    0x00 /*analog_channel_fixed3*/, 0x00 /*analog_channel_fixed2*/, analog_channel_fixed1, 
                    device_specific_status_14, device_specific_status_15, device_specific_status_16,
                    device_specific_status_17, device_specific_status_18, device_specific_status_19,
                    device_specific_status_20, device_specific_status_21, device_specific_status_22,
                    device_specific_status_23, device_specific_status_24 
                }
            }
        }
    }
}


/*****************************************************************
 * Dynamic Variables Configuration
 *****************************************************************/

VARIABLE temperatureValue
{
    LABEL "PV";
	HELP [sensor_temperature_help];
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE FLOAT
    {
       DISPLAY_FORMAT  "6.3f";
    }
}

VARIABLE temperatureUnits
{
    LABEL "Unit";
	HELP "Sensor Temperature Units- Engineering unit to be displayed with Sensor Temperature.";
    CLASS CORRECTION;
    HANDLING READ & WRITE;
    TYPE ENUMERATED
    { 
        UNITS_CODE(32),    // degrees C 
        UNITS_CODE(33),    // degrees F 
        UNITS_CODE(34),    // degress Rk
        UNITS_CODE(35),    // degress K 
        UNITS_CODE(36),    // mV 
        UNITS_CODE(58),    // V 
        UNITS_CODE(37),    // Ohm 
        UNITS_CODE(163)    // kOhm 
    }
}

VARIABLE temperatureUSL
{
    LABEL "Upper Sensor Limit";
    HELP [upper_sensor_limit_help];
    CLASS CORRECTION; 
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f"; 
    }
}

VARIABLE temperatureLSL
{
    LABEL "Lower Sensor Limit";
    HELP [lower_sensor_limit_help];
    CLASS CORRECTION;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE temperatureMinimumSpan
{
    LABEL "Minimum Span";
    HELP [minimum_span_help];
    CLASS CORRECTION;
    HANDLING READ;
    TYPE FLOAT
    {
        DISPLAY_FORMAT ".3f";
    }
}

VARIABLE temperatureDampingValue
{
    LABEL "Damping Value";
    HELP  [seconds_damping_value_help];
    CLASS CORRECTION;
    HANDLING READ & WRITE;
    CONSTANT_UNIT [sec];
    TYPE FLOAT
    {
       DISPLAY_FORMAT  ".1f";
       EDIT_FORMAT     "8.1f";
    } 
} 

VARIABLE temperatureSerialNumber
{
    LABEL "Sensor serial number";
    HELP [sensor_serial_number_help];
    CLASS DEVICE;
    HANDLING READ;
    TYPE UNSIGNED_INTEGER (3)
    {
        DISPLAY_FORMAT  "7d";    
    } 
}

COLLECTION OF VARIABLE temperature
{
    LABEL [temperature];
    HELP "";
    MEMBERS
    {
        // Sensor Correction Information 
        DIGITAL_VALUE,              temperatureValue,           [sv],                   [digital_value_help];
        DIGITAL_UNITS,              temperatureUnits,           [units],                [digital_units_help];
        UPPER_SENSOR_LIMIT,         temperatureUSL,             [usl],                  [upper_sensor_limit_help];
        LOWER_SENSOR_LIMIT,         temperatureLSL,             [lsl],                  [lower_sensor_limit_help];
        MINIMUM_SPAN,               temperatureMinimumSpan,     [minimum_span],         [minimum_span_help];
        DAMPING_VALUE,              temperatureDampingValue,    [damping_value],        [seconds_damping_value_help];   
        SENSOR_SERIAL_NUMBER,       temperatureSerialNumber,    [sensor_serial_number], [sensor_serial_number_help];
        TRANSFER_FUNCTION,          transfer_function,          [transfer_function],    [transfer_function_help];
     }
}

/**********************************************************
       deklaracja zmiennych dla MPT2
***********************************************************/

VARIABLE chan1Value
{
    LABEL "chan1Value";
    HELP  "Channel 1 value";                           
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE FLOAT
    {
       DISPLAY_FORMAT  "6.3f";
    }
}

VARIABLE chan1Unit
{
    LABEL "SV 1 unit";
	HELP "SV 1 Units- Engineering unit to be displayed with SV 1.";
    CLASS CORRECTION;
    HANDLING READ;
    TYPE ENUMERATED
    {
        UNITS_CODE(32),    // degrees C 
        UNITS_CODE(33),    // degrees F 
        UNITS_CODE(34),    // degress Rk 
        UNITS_CODE(35),    // degress K 
        UNITS_CODE(36),    // mV 
        UNITS_CODE(58),    // V 
        UNITS_CODE(37),    // Ohm 
        UNITS_CODE(163)    // kOhm 
    }
} 

COLLECTION OF VARIABLE sv1
{
    LABEL "SV 1";
    HELP  "Channel 1 value";
    MEMBERS 
    {
        DIGITAL_VALUE,              chan1Value,                 "Value",                [digital_value_help];
        DIGITAL_UNITS,              chan1Unit,                  [units],                [digital_units_help];
    }
}

VARIABLE chan2Value
{
    LABEL "chan2Value";
    HELP  "Channel 2 value";                                   
    CLASS CORRECTION & DYNAMIC;
    HANDLING READ;
    TYPE FLOAT
    {
       DISPLAY_FORMAT  "6.3f";
    }
}

VARIABLE chan2Unit
{
    LABEL "SV 2 unit";
	HELP "SV 2 Units- Engineering unit to be displayed with SV 2.";
    CLASS CORRECTION;
    HANDLING READ;
    TYPE ENUMERATED
    {
        UNITS_CODE(32),    // degrees C 
        UNITS_CODE(33),    // degrees F 
        UNITS_CODE(34),    // degress Rk 
        UNITS_CODE(35),    // degress K 
        UNITS_CODE(36),    // mV 
        UNITS_CODE(58),    // V 
        UNITS_CODE(37),    // Ohm 
        UNITS_CODE(163)    // kOhm 
    }                                                   
}  

COLLECTION OF VARIABLE sv2
{
    LABEL "SV 2";
    HELP  "Channel 2 value";
    MEMBERS 
    {
        DIGITAL_VALUE,              chan2Value,                 "Value",                [digital_value_help];
        DIGITAL_UNITS,              chan2Unit,                  [units],                [digital_units_help];
    }
}

VARIABLE cpuTemperatureValue
{
    LABEL "cpuTemperatureValue";
    HELP  [electronics_temperature_help];                               
    CLASS DEVICE & DYNAMIC;
    HANDLING READ;
    TYPE FLOAT
    {
       DISPLAY_FORMAT  "6.3f";
    }     
}

VARIABLE cpuTempUnit
{
    LABEL "CPU Temp unit";
	HELP "CPU Temp Units- Engineering unit to be displayed with CPU Temp.";
    CLASS CORRECTION;
    HANDLING READ;
    TYPE ENUMERATED
    {
        UNITS_CODE(32),    // degrees C 
        UNITS_CODE(33),    // degrees F 
        UNITS_CODE(34),    // degress Rk 
        UNITS_CODE(35)     // degress K 
    }
}

COLLECTION OF VARIABLE cpuTemperature
{
    LABEL "CPU Temp.";
    HELP  [electronics_temperature_help];
    MEMBERS 
    {
        DIGITAL_VALUE,              cpuTemperatureValue,         [temperature],          [digital_value_help];
        DIGITAL_UNITS,              cpuTempUnit,                 [units],                [digital_units_help];
    }
}

/******************* Device Variables *************************/

ARRAY OF COLLECTION deviceVariables 
{
    ELEMENTS
    {
        0, temperature, [pv];
        1, sv1, [sv];
        2, sv2, [tv];
        3, cpuTemperature, [qv];
    }
}

/**********************************************************
 * Relationships
 **********************************************************/   

UNIT temperatureUnitRelation
{
    temperatureUnits :
        temperatureValue,
        temperatureUSL,
        temperatureLSL,
        temperatureMinimumSpan,
        biasChan1,                  
        biasChan2                   
  }

UNIT chan1UnitRelation
{
    chan1Unit:
        chan1Value
}

UNIT chan2UnitRelation
{
    chan2Unit:
        chan2Value
} 

UNIT cpuTempUnitRelation
{
    cpuTempUnit:
        cpuTemperatureValue
}

/**********************************************************************
 *                     Configuration variables 
 **********************************************************************/

VARIABLE inputRange
{
    LABEL "Input Range";
    HELP  "Range selection between voltage and Resistance";
    CLASS INPUT;
    HANDLING  READ;
    TYPE ENUMERATED  
    {
          {0, " -10 - 100  mV", "Voltage range"},
          {1, "-100 - 1000 mV", "Voltage range"},
          {0x80, "0 - 400  ohm", "Resistance range"},
          {0x81, "0 - 2000 ohm", "Resistance range"}
    }
    POST_EDIT_ACTIONS
    {
        inputRange_post_read
    }
 }

 REFRESH fer_input_range
 {
     inputRange:
        temperatureUnits,
        temperatureValue,
        temperatureUSL,
        temperatureLSL,
        temperatureMinimumSpan,
        sensorType,
        sensorConnection,
        cjcType
 } 

  REFRESH fer_units
 {
     temperatureUnits:
        temperatureValue,
        temperatureUSL,
        temperatureLSL,
        temperatureMinimumSpan,
        PV.RANGING.UPPER_RANGE_VALUE,
        PV.RANGING.LOWER_RANGE_VALUE,
        biasChan1,
        biasChan2
 } 


/* Funkcja ustawia inputType w zalenoci od aktualnej wartosci inputRange */

METHOD inputRange_post_read
{
    LABEL "After Input Read Event Handle";
    HELP  "";                                       
    DEFINITION 
    {  
            ACKNOWLEDGE("WARNNING: Change units if input range units are different to transmitter units");          
    }  
} 

VARIABLE return_factory
{
    LABEL "kind of trim";
    HELP  "User calibrations (sensor calibrations) are replaced by the original factory calibrations.";
    CLASS LOCAL;
    HANDLING WRITE;
    DEFAULT_VALUE 3;
    TYPE ENUMERATED
    {
        { 0, "all settings", "undo all settings" },      
        { 1, "sensor trim", "sensor trim recall to factory settings"},
        { 2, "analog output trim", "analog output trim recall to factory settings"}
    }
}

METHOD return_to_factory_method                //ustawinie prdu 4 mA
{      
    LABEL   "Return to factory settings";
    DEFINITION
    {
        ACKNOWLEDGE("WARNING: Settings will return to their default values.");
        send_command(138);
    }
}

VARIABLE sensorConnection
{
    LABEL "Sensor connection";              
    HELP  [sensor_connection_help];
    CLASS INPUT;
    HANDLING  READ;
    TYPE ENUMERATED
    {
        IF ((inputRange == 0x80) || (inputRange == 0x81))
        {           
        { 0, "2-wire", [two_wires_help] },
        { 1, "3-wire", [three_wires_help] },
        { 2, "4-wire", [four_wires_help] },
        { 3, "2x2-wire", [differential_two_wires_help] },
        { 4, "2x3-wire", "help" }
        }  //end if
        IF ((inputRange == 0x00) || (inputRange == 0x01))
        {            
        { 0, "Single connection", "help" },
        { 1, "Single connection", "help" },
        { 2, "Single connection", "help" },
        { 3, "Double connection", "help" },
        { 4, "Double connection", "help" },
        { 5, "Double connection", "help" }
        }          //end if       
    } //type  
}   //variable



VARIABLE cjcType
{
    LABEL "CJC Type";
    HELP  "Type of CJC";                               
    CLASS INPUT;
    HANDLING READ;
    TYPE ENUMERATED
    {
        IF ((inputRange == 0x00) || (inputRange == 0x01))
        {  //if          
            { 0, "No CJC", "help" },
            { 1, "Internal/Remote CJC", "help" },
            { 2, "External CJC", "help" }
        }  //end if 
        ELSE
        {
           {0 , "NONE", "help" }
        }              
    }  //type enumerated
}


VARIABLE externalCJCValue
{
    LABEL "Extern. CJC";
    HELP  "Fixed temperature value of an external reference junction";                            
    CLASS CORRECTION;
    HANDLING READ;
    DEFAULT_VALUE 0;
    TYPE FLOAT
    {
       DISPLAY_FORMAT  "6.3f";
       EDIT_FORMAT     "6.3f";
    }
}

VARIABLE externalCJCUnit
{
    LABEL "External CJC Unit";
    HELP  "External CJC Unit";                      
    CLASS CORRECTION;
    HANDLING READ;
    TYPE ENUMERATED
    {
        UNITS_CODE(32),    // degrees C 
        UNITS_CODE(33),    // degrees F 
        UNITS_CODE(34),    // degress Rk 
        UNITS_CODE(35)     // degress K 
    }
}

//Units

UNIT externalCJCUnitRelation
{
    externalCJCUnit:
        externalCJCValue
}

//VARIABLE
VARIABLE sensorType
{
    LABEL "Sensor Type";
    HELP  [sensor_type_help];
    CLASS INPUT;
    HANDLING READ;
    TYPE ENUMERATED
    {
       //IF (inputType > 0)
        IF ((inputRange == 0x80) || (inputRange == 0x81))
        {
            { 0,   "No linearyzation" },
            { 1,   "Linearyzation table" },
            { 100, "Pt10 a=0.003850",   "RTD Pt10 a=0.003850 (IEC 751, DIN 43760, JIS C1604-97, BS1904)" },
            { 101, "Pt50 a=0.003850",   "RTD Pt50 a=0.003850 (IEC 751, DIN 43760, JIS C1604-97, BS1904)" },
            { 102, "Pt100 a=0.003850",  "RTD Pt100 a=0.003850 (IEC 751, DIN 43760, JIS C1604-97, BS1904)" },
            { 103, "Pt200 a=0.003850",  "RTD Pt200 a=0.003850 (IEC 751, DIN 43760, JIS C1604-97, BS1904)" },
            { 104, "Pt500 a=0.003850",  "RTD Pt500 a=0.003850 (IEC 751, DIN 43760, JIS C1604-97, BS1904)" },
            { 105, "Pt1000 a=0.003850", "RTD Pt1000 a=0.003850 (IEC 751, DIN 43760, JIS C1604-97, BS1904)" },
            { 108, "Pt100 a=0.003916",  "RTD Pt100 a=0.003916 (JIS C1604-81)" },
            { 240, "Pt98 a=0.003023",   "RTD Pt98 a=0.003023 (SAMA RC-4)" },
            { 241, "Ni100",             "RTD Ni100 (PN-83/M-53952)" },
            { 242, "Cu100",             "RTD Cu100 (PN-83/M-53952)" }
        }
        IF ((inputRange == 0x00) || (inputRange == 0x01))
        {
            { 0,   "No linearyzation" },
            { 1,   "Linearyzation table" },
            { 128, "TC Type B", "TC Type B, Pt30Rh-Pt6Rh (IEC 584, NIST MN 175, DIN 43710, BS 4937, ANSI MC96.1, JIS C1602, NF C42-321)" },
            { 131, "TC Type E", "TC Type E, Ni10Cr-Cu45Ni (IEC584, NIST MN 175, DIN 43710, BS 4937, ANSI MC96.1, JIS C1602, NF C42-321)" },
            { 133, "TC Type J", "TC Type J, Fe-Cu45Ni (IEC 584, NIST MN 175, DIN 43710, BS 4937, ANSI MC96.1, JIS C1602, NF C42-321)" },
            { 134, "TC Type K", "TC Type K, Ni10Cr-Ni5 (IEC 584, NIST MN 175, DIN 43710, BS 4937, ANSI MC96.1, JIS C1602, NF C42-321)" },
            { 135, "TC Type N", "TC Type N, Ni14CrSi-NiSi (IEC 584, NIST MN 175, DIN 43710, BS 4937, ANSI MC96.1, JIS C1602, NF C42-321)" },
            { 136, "TC Type R", "TC Type R, Pt13Rh-Pt (IEC 584, NIST MN 175, DIN 43710, BS 4937, ANSI MC96.1, JIS C1602, NF C42-321)" },
            { 137, "TC Type S", "TC Type S, Pt10Rh-Pt (IEC 584, NIST MN 175, DIN 43710, BS 4937, ANSI MC96.1, JIS C1602, NF C42-321)" },
            { 138, "TC Type T", "TC Type T, Cu-Cu45Ni (IEC 584, NIST MN 175, DIN 43710, BS 4937, ANSI MC96.1, JIS C1602, NF C42-321)" }
        }  
    }  
} 

REFRESH sensor_type_relation
{
    sensorType:
        temperatureValue
        temperatureUSL,
        temperatureLSL,
        temperatureMinimumSpan
}  
 
VARIABLE sensorMeasType
{
    LABEL "Sensor Meas Type";
    HELP  "Mathematical function to calculate PRIMARY VARIABLE (PV)";                   
    CLASS COMPUTATION;
    HANDLING READ;
    TYPE ENUMERATED
    {
        { 0,  "Channel 1"},
        { 1,  "Channel 2"},
        { 128,"Channel 1 minus Channel 2"},
        { 129,"Channel 2 minus Channel 1"},
        { 220,"Minimum of CH1 and CH2"},
		{ 221,"Maximum of CH1 and CH2"},
        { 192,"Average of Ch1 and Ch2"},
        { 193,"Average of Ch1 and Ch2 but Ch1 or Ch2 if the other is wrong"}
    }
}

VARIABLE biasChan1
{
    LABEL "Bias, Chan 1";
    HELP  "Bias can be algebraically added to process value of channel 1";            
    CLASS CORRECTION;
    HANDLING READ;
    DEFAULT_VALUE 0;
    TYPE FLOAT
    {
       DISPLAY_FORMAT  "6.3f";
       EDIT_FORMAT     "6.3f";
    }    
}

VARIABLE biasChan2
{
    LABEL "Bias Chan 2";
    HELP  "Bias can be algebraically added to process value of channel 2";           
    CLASS CORRECTION;
    HANDLING READ;
    DEFAULT_VALUE 0;
    TYPE FLOAT
    {
       DISPLAY_FORMAT  "6.3f";
       EDIT_FORMAT     "6.3f";
    }
}

VARIABLE biasUnit
{
    LABEL "bias Unit";
    HELP  "Bias units";                           
    CLASS CORRECTION;
    HANDLING READ;
    TYPE ENUMERATED
    {
        UNITS_CODE(32),    // degrees C 
        UNITS_CODE(33),    // degrees F 
        UNITS_CODE(34),    // degress Rk 
        UNITS_CODE(35),    // degress K 
        UNITS_CODE(36),    // mV 
        UNITS_CODE(58),    // V 
        UNITS_CODE(37),    // Ohm 
        UNITS_CODE(163)    // kOhm 
    }
}

UNIT biasUnitRelation
{
    biasUnit:
        biasChan1,
        biasChan2
}

VARIABLE wireResCompensationChan1
{
    LABEL "Wire Res. Comp. 1";
    HELP  "Value in OHM to compensate line resistance when the thermoresistance 1 is connected with 2 or 3 wires";
    CLASS CORRECTION;
    HANDLING READ;
    DEFAULT_VALUE 0;
    CONSTANT_UNIT [Ohm];
    TYPE FLOAT
    {
       DISPLAY_FORMAT  "6.3f";
       EDIT_FORMAT     "6.3f";
    } 
}

VARIABLE wireResCompensationChan2
{
    LABEL "Wire Res. Comp. 2";
    HELP  "Value in OHM to compensate line resistance when the thermoresistance 2 is connected with 2 or 3 wires";
    CLASS CORRECTION;
    HANDLING READ;
    DEFAULT_VALUE 0;
    CONSTANT_UNIT [Ohm];
    TYPE FLOAT
    {
       DISPLAY_FORMAT  "6.3f";
       EDIT_FORMAT     "6.3f";
    }
}
 

/*******************************************************************************
               Output Configuration - variable
********************************************************************************/

VARIABLE namur_mode
{
    LABEL "Current range mode";
    HELP  "Current range mode";              
    CLASS DEVICE;
    HANDLING READ & WRITE;
    TYPE ENUMERATED
    {
        { 0x00, "Normal", "Normal (3,9  20,5 mA)" },
        { 0x01, "NAMUR", "NAMUR (3,8  20,5 mA)" }
    }
}

VARIABLE alarm_mode
{
    LABEL "Namur mode and alarm current mode";
    HELP  "Namur mode and alarm current mode";              
    CLASS DEVICE;
    HANDLING READ & WRITE;
    TYPE ENUMERATED
    {
        { 0x00, "Low", "" },
        { 0x40, "High", ""},
        { 0x08, "Last Value", "" },
        { 0x20, "Custom Alarm", ""}    
    }
}

VARIABLE custom_alarm_current_mode
{
    LABEL "Custom alarm value";
    HELP  "Custom alarm value";                       
    CLASS DEVICE;
    HANDLING READ & WRITE;
    CONSTANT_UNIT "mA";
    DEFAULT_VALUE 3.8;
    TYPE FLOAT
    {
       DISPLAY_FORMAT  ".2f";
       EDIT_FORMAT     ".3f";
    } 
}

VARIABLE temperature_UTL
{
    LABEL "Upper temp. limit";
    HELP  "Upper temperature limit";
    CLASS DEVICE;
    HANDLING READ;
    TYPE FLOAT
    {
       DISPLAY_FORMAT  "6.3f";
    }

}

VARIABLE temperature_LTL
{
    LABEL "Lower temp. limit";
    HELP  "Lower temperature limit";
    CLASS DEVICE;
    HANDLING READ;
    TYPE FLOAT
    {
       DISPLAY_FORMAT  "6.3f";
    }
}

/* Zmienna uywana przez sub_CMD_202 i 203 (do kalibracji) */
VARIABLE input_value
{
    LABEL "Input value";
    HELP  "Input value";
    CLASS LOCAL;
    HANDLING WRITE;
    DEFAULT_VALUE 0;
    TYPE FLOAT
    {
       DISPLAY_FORMAT  "6.3f";
    }
}

VARIABLE limitsUnit
{
    LABEL "Limits Unit";
    HELP  "Limits Unit";                
    CLASS DEVICE;
    HANDLING READ;
    TYPE ENUMERATED
    {
        UNITS_CODE(32),    // degrees C 
        UNITS_CODE(33),    // degrees F 
        UNITS_CODE(34),    // degress Rk 
        UNITS_CODE(35),    // degress K 
        UNITS_CODE(36),    // mV 
        UNITS_CODE(58),    // V 
        UNITS_CODE(37),    // Ohm 
        UNITS_CODE(163)    // kOhm 
    }
}

UNIT temp_limits
{
    limitsUnit:
        temperature_LTL,
        temperature_UTL
}

//change security code
VARIABLE old_customer_code
{
    LABEL "Old customer security code";
    HELP  "Old customer security code";
    CLASS DEVICE;
    HANDLING WRITE;
    TYPE INTEGER (4);
    DEFAULT_VALUE  0;

}

VARIABLE new_customer_code
{
    LABEL "New customer security code";
    HELP  "New customer security code";
    CLASS DEVICE;
    HANDLING WRITE;
    TYPE INTEGER (4);
    DEFAULT_VALUE  0;
    POST_EDIT_ACTIONS
    {
        m_246
    }
}

METHOD m_246
{
    LABEL "";
    HELP  "";
    DEFINITION 
    {  
        send_command(246);
    }
}
VARIABLE protect_code
{
    LABEL "Customer code";
    HELP  "Customer code";              
    CLASS DEVICE;
    HANDLING WRITE;
    DEFAULT_VALUE 0;
    TYPE INTEGER (4);
} 

/**********************************************************************************************/

/*************************Obsuga LCD *********************************************************************/

VARIABLE local_keys_mode_control_codes
{
	LABEL           "Local Operation";
	HELP            "Local Operation";
    CLASS           LOCAL_DISPLAY;
    DEFAULT_VALUE   0;
	TYPE            ENUMERATED
    {
  		{ 0,    "Enabled" },
		{ 1,    "Disabled" }
    }
    HANDLING    READ & WRITE;
}


VARIABLE meter_information_configuration
{
    LABEL               "Meter Information Configuration";
    HELP                [meter_information_configuration_help];
    CLASS               LOCAL_DISPLAY;
    TYPE                ENUMERATED
    {
		{0,     [not_installed]},
		{1,     "Integral LCD" }
    }
    HANDLING    READ & WRITE;
}

VARIABLE meter_display_mode
{
    LABEL               "Meter display mode";
    HELP                "Meter display mode";
    CLASS               LOCAL_DISPLAY;
    DEFAULT_VALUE       0;
    TYPE 		ENUMERATED
    {
  	    { 0, "Unit On"},
   	    { 1, "Unit Off"}
    }
  HANDLING    READ & WRITE;
}

VARIABLE meter_display_electronics_bias_control
{
    LABEL               "Meter display contrast";
    HELP                "Meter display contrast";
    CLASS               LOCAL_DISPLAY;
    DEFAULT_VALUE       0;
    TYPE 		ENUMERATED
	{
        {0, "NOT USED"}    
	}
    HANDLING    READ & WRITE;
}

VARIABLE LCD1_display_variable
{
    LABEL               "LCD1 display variable";
    HELP                "LCD1 display variable";
    CLASS               LOCAL_DISPLAY;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
 		{0,     "Current"},
		{1,     "Percent of Range" }
    }
    HANDLING    READ & WRITE;
}

VARIABLE LCD2_display_variable
{
    LABEL               "LCD2 display variable";
    HELP                "LCD2 display variable";
    CLASS               LOCAL_DISPLAY;
	//DEFAULT_VALUE       0;
    TYPE                ENUMERATED(2)
    {
		{2,     "PV" },
		{3,     "User Rerange"},
        {0,     "PV, no unit displayed" },
        {1,     "User Rerange, no unit displayed"}
    }
    HANDLING    READ & WRITE;
}

VARIABLE LCD_gap
{
    LABEL               "LCD gap";
    HELP                "LCD gap";
    CLASS               LOCAL_DISPLAY;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
            {0,     "GAP"}
    }
    HANDLING    READ & WRITE;
}

VARIABLE meter_display_variable_decimal_point
{
    LABEL               "Meter display decimal point";
    HELP                "Meter display decimal point";
    CLASS               LOCAL_DISPLAY;
    DEFAULT_VALUE       6;
    TYPE                ENUMERATED
    {
        {1,     "[.XXXXX]" },
		{2,     "[X.XXXX]" },
		{3,     "[XX.XXX]" },
		{4,     "[XXX.XX]" },
		{5,     "[XXXX.X]" },
		{6,     "[XXXXX.]" }
    }
    HANDLING    READ & WRITE;
}

VARIABLE    users_unit
{
	LABEL           "Users Unit";
    HELP            "Display Unit - Unit that is displayed on the LCD Display";
	CLASS           DEVICE;
	TYPE            ASCII(7);
    HANDLING READ & WRITE;
}

VARIABLE rearrange_shift
{
	LABEL           "Rearrange Shift";
	HELP            "Rearrange Shift";
	CLASS           CORRECTION;
	TYPE            FLOAT ;
	HANDLING READ & WRITE;
}

VARIABLE rearrange_ampl
{
	LABEL           "Rearrange Ampl";
	HELP            "Rearrange Ampl";
	CLASS           CORRECTION;
	TYPE            FLOAT ;
	HANDLING READ & WRITE;
}

COMMAND read_control_modes
{
	NUMBER 133;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{}
		REPLY
		{
			response_code,device_status, 		/* U8 */
			local_keys_mode_control_codes, 	/* U8 */
			meter_information_configuration,   /* U8 */
			meter_display_mode,  	/* U8 */
			meter_display_electronics_bias_control,   /* U8 */
			//meter_display_variable,  	/* U8 */
            LCD_gap               <0xF0>, 
            LCD2_display_variable <0x0C>,
            LCD1_display_variable <0x03>,
			meter_display_variable_decimal_point	/* U8 */
		}
	}
	RESPONSE_CODES
	{
		0,  SUCCESS,                    			[no_command_specific_errors];
	}
}

COMMAND write_control_modes
{
	NUMBER 132;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			local_keys_mode_control_codes, 	/* U8,  0 = enabled. 1 = disabled */
			meter_information_configuration, 	/* U8, 0 = not_installed, 1 = integral_LCD */
			meter_display_mode, 			/* U8, 0=unit_on, 1=unit_off */
			meter_display_electronics_bias_control,	/* U8, not used */
			//meter_display_variable, 	/* U8 */
            LCD_gap               <0xF0>,  
            LCD2_display_variable <0x0C>,
            LCD1_display_variable <0x03>,
							/*{BIT1,BIT0=00,     [LCD1  current]},
							{BIT1,BIT0=01,     [LCD1  percent_of_range]},

							{BIT3,BIT2=00,     [LCD2  pressure]},
							{BIT3,BIT2=01,     [LCD2  user_rerange]},*/

			meter_display_variable_decimal_point	/* U8
                            {1,     	[.XXXXX]},
							{2,     	[X.XXXX]},
							{3,     	[XX.XXX]},
							{4,     	[XXX.XX]},
							{5,     	[XXXX.X]},
							{6,     	[XXXXX.]}
							*/
		}
		REPLY
		{
			response_code,device_status, 		/* U8 */
			local_keys_mode_control_codes,  	/* U8 */
			meter_information_configuration,	/* U8 */
			meter_display_mode,  	/* U8 */
			meter_display_electronics_bias_control,   /* U8 */
			//meter_display_variable, 	/* U8 */
            LCD_gap               <0xF0>, 
            LCD2_display_variable <0x0C>,
            LCD1_display_variable <0x03>,
			meter_display_variable_decimal_point /* U8 */
		}
	}
	RESPONSE_CODES
	{
		0,  SUCCESS,                    [no_command_specific_errors];
		2,  DATA_ENTRY_ERROR,           [invalid_selection];
		5,  MISC_ERROR,                 [too_few_data_bytes_recieved];
		7,  MODE_ERROR,				    [in_write_protect_mode];
	}
}

COMMAND write_users_unit_name_and_rearrange_coefficients
{
	NUMBER 242;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{       
			users_unit,     			/* string w formacie ASCII(7) */
			rearrange_shift,			/* IEE754 float, jest to przeskalowanie LRV wywietlane na LCD w trybie user_rearrange.*/
			rearrange_ampl  			/* IEE754 float, jest to przeskalowanie URV wywietlane na LCD w trybie user_rearrange. */
		}
		REPLY
		{
			response_code,device_status, 		/* U8 */
			users_unit,             			/* string w formacie ASCII(7) */
			rearrange_shift,        			/* IEE754 float */
			rearrange_ampl          			/* IEE754 float */
		}
	}
	RESPONSE_CODES
	{
		0,  SUCCESS,                    			[no_command_specific_errors];
		5,  MISC_ERROR,                 			[too_few_data_bytes_recieved];
		7,  MODE_ERROR,                 			[in_write_protect_mode];   
	}
}
/**********************************************************************************************/
COMMAND read_users_unit_name_and_rerange_coefficients
{
	NUMBER 243;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{       

		}
		REPLY
		{
			response_code,device_status, 		/* U8 */
			users_unit,             			/* string w formacie ASCII(7) */
			rearrange_shift,         			/* IEE754 float */
			rearrange_ampl          			/* IEE754 float */
		}
	}
	RESPONSE_CODES
	{
		0,  SUCCESS,                    			[no_command_specific_errors];
	}
}

MENU menu_lcd
{
    LABEL "LCD";
    ITEMS 
    {  
        menu_local_LCD,
        menu_user_unit,
        //users_unit (DISPLAY_VALUE),
        menu_user_rarange
        //rearrange_shift (DISPLAY_VALUE),
        //rearrange_ampl (DISPLAY_VALUE)
    }
}

MENU menu_local_LCD
{
    LABEL "Local LCD";
    ITEMS 
    {  
        local_keys_mode_control_codes (DISPLAY_VALUE),
        meter_information_configuration (DISPLAY_VALUE),       
        LCD2_display_variable (DISPLAY_VALUE),
        LCD1_display_variable (DISPLAY_VALUE),
        meter_display_variable_decimal_point (DISPLAY_VALUE)//,
        //[blank]

    }
}

MENU menu_user_unit
{
    LABEL "User Unit";
    HELP "Display Unit - Unit that is displayed on the LCD Display";
    ITEMS 
    {  
    users_unit (DISPLAY_VALUE)//,
    //[blank]
    }
}

MENU menu_user_rarange
{
    LABEL "User Rerange";
    HELP "User Rerange";
    ITEMS 
    {  
    //[blank],
    rearrange_shift (DISPLAY_VALUE),
    rearrange_ampl (DISPLAY_VALUE)//,
    //[blank]
    }
}

/********************************************************************************
*                   SERVICE COMMANDS
*********************************************************************************/
/********************************************************************************
;                           sub_CMD_202                                         ;
; Kalibracja toru wejciowego.                                                  ;
; Kalibrowany jest zawsze biecy zakres przetwornika.                          ;
;--------------------------------------------------------------------------------
; ;               byte 0 - bajt jednostek danych                                ;
;               byte 1-4 - dolny punkt dla kalibracji (IEEE754)                 ;                                             ;
;********************************************************************************/

COMMAND calibrate_zero_frame
{
    NUMBER 202;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            temperatureUnits, input_value
        }
        REPLY
        {
         response_code, device_status, temperatureUnits, input_value
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,          [no_command_specific_errors];
        2,  DATA_ENTRY_ERROR, [invalid_selection];
        5,  DATA_ENTRY_ERROR, [too_few_data_bytes_recieved];
        7,  MODE_ERROR,       [in_write_protect_mode];
        9,  DATA_ENTRY_ERROR,  "Error in DS33";  // -status w ds33 w. mierzonej != GOOD                           ;
       10,  DATA_ENTRY_ERROR,  "Coefficient Zero and Span are equel)";
       11,  DATA_ENTRY_ERROR,  "Communication Error"; 
    }
}        

/********************************************************************************
;                           sub_CMD_203                                         ;
;                     kalibracja toru wejsciowego                               ;
;--------------------------------------------------------------------------------
;                 byte 0 - bajt jednostek danych                               ;
;               byte 1-4 - gorny punkt dla kalibracji (IEEE754)                 ;                                             ;
;********************************************************************************/

COMMAND calibrate_gain_frame
{
    NUMBER 203;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            temperatureUnits ,input_value
        }
        REPLY
        {
          response_code, device_status, temperatureUnits, input_value   
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,          [no_command_specific_errors];
        2,  DATA_ENTRY_ERROR, [invalid_selection];
        5,  DATA_ENTRY_ERROR, [too_few_data_bytes_recieved];
        7,  MODE_ERROR,       [in_write_protect_mode];
        9,  DATA_ENTRY_ERROR,  "Error in DS33";  // -status w ds33 w. mierzonej != GOOD                           ;
       10,  DATA_ENTRY_ERROR,  "Coefficient Zero and Span are equel";
       11,  DATA_ENTRY_ERROR,  "Communication Error"; 
    }
} 


/********************************************************************************
;               sub_CMD_150      READ Zakres Kompensaci Temperaturowej          ;
;--------------------------------------------------------------------------------
;				byte 0	   Jednostka					                        ;
;               byte 1-4   Dolna Granica Zakresu Kompensacji Temperaturowej     ;
;               byte 5-8   Grna Granica Zakresu Kompensacji Temperaturowej     ;
;-------------------------------------------------------------------------------;
;OPIS:                                                                          ;
;   Dolna Granica Zakresu - Warto ta powinna by doln granic temperatury dla;
;	                    	ktrej przetwornik zosta skompensowany.            ;
;   Grna Granica Zakresu - Warto ta powinna by grn granic temperatury dla;
;					        ktrej przetwornik zosta skompensowany		        ;
;*******************************************************************************/

 COMMAND sub_CMD_150
{
    NUMBER 150;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
            
        }
        REPLY
        {
            response_code, device_status, limitsUnit, temperature_LTL, temperature_UTL  
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,          [no_command_specific_errors];
    }
}

/********************************************************************************
;                           sub_CMD_145   (0x91)                                ;
;         READ - INPUT_RANGE+SENSOR_CONNECTION+RJ_TYPE+SENSOR_TYPE              ;
;--------------------------------------------------------------------------------
; byte 0 - eep_INPUT_RANGE - electrical input range and mode                    ;
; byte 1 - eep_SENSOR_CONNECTION - connection to the sensor                     ;
; byte 2 - eep_RJ_TYPE - select reference junction from internal to fixed value ;
; byte 3 - eep_SENSOR_TYPE - select the type of sensor for Thermocouples etc.   ;
; byte 4 - eep_SENSOR_MEAS_TYPE -                                               ;
;********************************************************************************/

COMMAND readMainConfiguration
{
    NUMBER 145;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            response_code, device_status, inputRange, sensorConnection, cjcType, sensorType, sensorMeasType 
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,          [no_command_specific_errors];
        2,  DATA_ENTRY_ERROR, [invalid_selection];
        3,  DATA_ENTRY_ERROR, [passed_parameter_too_large];
        4,  DATA_ENTRY_ERROR, [passed_parameter_too_small];
        5,  DATA_ENTRY_ERROR, [too_few_data_bytes_recieved];
        7,  MODE_ERROR,       [in_write_protect_mode];
        16, MODE_ERROR,       [access_restricted];
        32, MODE_ERROR,       [busy];
    }
}        
            
/**********************************************************************************************
;                         sub_CMD_138  (0x8A)     RESET FACTORY TRIM
;**********************************************************************************************
;				0x00	undo all settings
;				0x01	sensor trim recall to factory settings (undo CMD_202 and 203)
;				0x02	analog output trim recall to factory settings (undo CMD_45 i 46)
;--------------------------------------------------------------------------------------------*/

COMMAND reset_factory_trim
{
    NUMBER 138;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            return_factory
        }
        REPLY
        {
            response_code, device_status, return_factory
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,          [no_command_specific_errors];
        2,  DATA_ENTRY_ERROR, [invalid_selection];
        5,  DATA_ENTRY_ERROR, [too_few_data_bytes_recieved];
        7,  MODE_ERROR,       [in_write_protect_mode];
        9,  DATA_ENTRY_ERROR, "Error";
    }
}

/**********************************************************************************************
;                         sub_CMD_143  (0x8F)     READ EXTERNAL_RJ_VALUE, BIAS, COMP_WIRE
;----------------------------------------------------------------------------------------------
;                               byte 0      - EXTERNAL_RJ_VALUE_UNIT                          ;
;                               byte 1-4    - EXTERNAL_RJ_VALUE   (F)                         ;
;                               byte 5      - BIAS_UNIT                                       ;
;                               byte 6-9    - BIAS_CH1            (F)                         ;
;                               byte 10-13  - BIAS_CH2            (F)                         ;
;                               byte 14     - COMP_WIRE_UNIT                                  ;
;                               byte 15-18  - eep_COMP_WIRE_1     (F)                         ;
;                               byte 19-22  - COMP_WIRE_2         (F)                         ;
;**********************************************************************************************/

COMMAND CMD_143
{
    NUMBER 143;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            response_code, device_status, externalCJCUnit, externalCJCValue, biasUnit, biasChan1, biasChan2 , 37, wireResCompensationChan1, wireResCompensationChan2 
        }
    }
    RESPONSE_CODES
    {
        0,  SUCCESS,          [no_command_specific_errors];
        16, MODE_ERROR,       [access_restricted];
        32, MODE_ERROR,       [busy];
    }
}

/********************************************************************************
;		sub_CMD_246	 CHANGE CUSTOMER SECURITY CODE		(8 bajtw danych)
;********************************************************************************
;                   byte 0-3 - old customer security code                       
;                   byte 3-7 - new customer security code
;-------------------------------------------------------------------------------;
;OPIS:                                                                          ;
;              Umoliwia zmian kodu zabezpieczajcego                          ;
;------------------------------------------------------------------------------*/

COMMAND CMD_246
{
    NUMBER 246;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
           old_customer_code, new_customer_code
        }
        REPLY
        {
            response_code, device_status, old_customer_code, new_customer_code 
         }
    }
    RESPONSE_CODES
    {
      0,  SUCCESS,          [no_command_specific_errors];
      5,  DATA_ENTRY_ERROR, [too_few_data_bytes_recieved];
      16, MISC_ERROR,       [access_restricted];
    }
}     
   
/*******************************************************************************;
;		sub_CMD_247	SET WRITE PROTECT CODE	(5 bajtw danych)                   ;
;*******************************************************************************;
;                   byte 0-3 - customer security code                           ;
;                   byte 4 - write protect code                                 ;
;-------------------------------------------------------------------------------;
;OPIS:                                                                          ;
;              Po wpisaniu odpowiedniego kodu ustawiany jest write protect code ;
;------------------------------------------------------------------------------*/
 
COMMAND CMD_247
{
    NUMBER 247;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
           protect_code, write_protect 
        }
        REPLY
        {
            response_code, device_status, protect_code, write_protect 
         }
    }
    RESPONSE_CODES
    {
      0,  SUCCESS,          [no_command_specific_errors];
      2,  DATA_ENTRY_ERROR, [invalid_selection];
      5,  DATA_ENTRY_ERROR, [too_few_data_bytes_recieved];
      16, MISC_ERROR,       [access_restricted];
    }
}  
 
//zmienne do errorw

VARIABLE variable1
{
    LABEL "variable1";
    HELP  "";
    CLASS LOCAL;
    HANDLING READ;
    TYPE ENUMERATED
    {
        { 1, "description", "help" }
    }
}

VARIABLE hot_start_occure
{
    LABEL               "Hot start occure error";
    HELP                "Hot start occure alarm";
    CLASS               LOCAL;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}

VARIABLE output_current_fixed
{
    LABEL               "Output current fixed error";
    HELP                "Output current fixed alarm";
    CLASS               LOCAL;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}

VARIABLE ram_error
{
    LABEL               "RAM test error";
    HELP                "RAM test error alarm";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}

VARIABLE flash_test_error
{
    LABEL               "Flash CRC error";
    HELP                "Flash CRC alarm";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}
VARIABLE badcrc_in_segment_info
{
    LABEL               "Bad CRC in segment INFO error";
    HELP                "Bad CRC in segment INFO alarm";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}
VARIABLE oscillator_fault
{
    LABEL               "Oscillator fault";
    HELP                "Oscillator fault alarm";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}

VARIABLE ht430_init_error
{
    LABEL               "Modem error";
    HELP                "HT430 initialization error";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}

VARIABLE adc_interface_master_error
{
    LABEL               "ADC interface master error";
    HELP                "ADC interface master alarm";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}
VARIABLE adc_interface_slave_error
{
    LABEL               "ADC interface slave error";
    HELP                "ADC interface slave alarm";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}
VARIABLE adc_not_responded
{
    LABEL               "ADC not responded error";
    HELP                "ADC not responded alarm";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}
VARIABLE sensor_failure
{
    LABEL               "Sensor failure error";
    HELP                "Sensor failure alarm";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}
VARIABLE sensor_not_connected
{
    LABEL               "Sensor not connected error";
    HELP                "Sensor not connected alarm";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}
VARIABLE primary_variable_not_valid
{
    LABEL               "Primary variable not valid error";
    HELP                "Primary variable not valid alarm";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}

VARIABLE primary_variable_out_of_limits
{
    LABEL               "Primary variable out of limits error";
    HELP                "Primary variable out of limits alarm";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}
VARIABLE secondary_variable_out_of_limits
{
    LABEL               "Secondary variable out of limits error";
    HELP                "Secondary variable out of limits alarm";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}
VARIABLE analog_output_saturated
{
    LABEL               "Analog output saturated error";
    HELP                "Analog output saturated alarm";
    CLASS               DEVICE;
	DEFAULT_VALUE       0;
    TYPE                ENUMERATED
    {
		{0x00,     "Disabled" },
		{0x01,     "Enabled" }
    }
    HANDLING    READ & WRITE;
}

/********************************************************************************
;        sub_CMD_139 (0x8B)         READ CurrentConfig                   	    ;
;--------------------------------------------------------------------------------
;	Dane Odpowiedzi:							                                ;
;                            byte 0     - Imode                              	;
;			                 byte 1-2   - AlarmMask				                ;
;                            byte 3-6   - CustomAlarmCurrent                (F) ;
;-------------------------------------------------------------------------------;
;OPIS:   Ustawia parametry konfiguracji prdu. Funkcja zwraca kody operacji     ;
;*******************************************************************************/

COMMAND read_current_config
{
    NUMBER 139;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {            
        }
        REPLY
        {
            response_code, device_status, namur_mode <0x80>, alarm_mode <0x7f>,

            hot_start_occure <0x80>,
            output_current_fixed <0x40>,
            analog_output_saturated <0x20>,
            secondary_variable_out_of_limits <0x10>,
            primary_variable_out_of_limits <0x08>,
            primary_variable_not_valid <0x04>,
            sensor_not_connected <0x02>,
            sensor_failure <0x01>,
            adc_not_responded <0x80>,
            adc_interface_slave_error <0x40>,
            adc_interface_master_error <0x20>,
            ht430_init_error <0x10>,
            oscillator_fault <0x08>,
            badcrc_in_segment_info <0x04>,
            flash_test_error <0x02>,
            ram_error <0x01>,
            custom_alarm_current_mode 
        }
    }
    RESPONSE_CODES
    {
      0,  SUCCESS,          [no_command_specific_errors];
    }
}    

/********************************************************************************
;        sub_CMD_140 (0x8C)         WRITE -  setCurrentConfig                   ;
;--------------------------------------------------------------------------------
;                               byte 0     - Imode                              ;
;				                byte 1-2   - AlarmMask				            ;
;                               byte 3-6   - CustomAlarmCurrent (F)             ;
;-------------------------------------------------------------------------------;
;OPIS:   Ustawia parametry konfiguracji prdu. Funkcja zwraca kody operacji     ;
;*******************************************************************************/ 

COMMAND write_current_config
{
    NUMBER 140;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {      //1          //+2        //+4            //=7
            namur_mode <0x80>, alarm_mode <0x7f>, 

            hot_start_occure <0x80>,
            output_current_fixed <0x40>,
            analog_output_saturated <0x20>,
            secondary_variable_out_of_limits <0x10>,
            primary_variable_out_of_limits <0x08>,
            primary_variable_not_valid <0x04>,
            sensor_not_connected <0x02>,
            sensor_failure <0x01>,
            adc_not_responded <0x80>,
            adc_interface_slave_error <0x40>,
            adc_interface_master_error <0x20>,
            ht430_init_error <0x10>,
            oscillator_fault <0x08>,
            badcrc_in_segment_info <0x04>,
            flash_test_error <0x02>,
            ram_error <0x01>,
            custom_alarm_current_mode
        }
        REPLY
        {
            response_code, device_status, namur_mode <0x80>, alarm_mode <0x7f>, 

            hot_start_occure <0x80>,
            output_current_fixed <0x40>,
            analog_output_saturated <0x20>,
            secondary_variable_out_of_limits <0x10>,
            primary_variable_out_of_limits <0x08>,
            primary_variable_not_valid <0x04>,
            sensor_not_connected <0x02>,
            sensor_failure <0x01>,
            adc_not_responded <0x80>,
            adc_interface_slave_error <0x40>,
            adc_interface_master_error <0x20>,
            ht430_init_error <0x10>,
            oscillator_fault <0x08>,
            badcrc_in_segment_info <0x04>,
            flash_test_error <0x02>,
            ram_error <0x01>,
            custom_alarm_current_mode 
         }
    }
    RESPONSE_CODES
    {
      0,  SUCCESS,          [no_command_specific_errors];
    }
}    


/*########################################################################
                koniec service commands
#########################################################################*/


/***************************************************************************
                                MENU
 ***************************************************************************/

MENU root_menu
{
    STYLE WINDOW; 
    LABEL [bus_devices];
    ITEMS
    {   
        menu_input
        device_setup
        menu_output
        menu_lcd
    }
}

MENU menu_input
{
    LABEL "Input Configuration";
    ITEMS 
    {  
        current_por,        
        process_value,
        menu_input_type,
        menu_sensor_connections,
        input_calibration,
        additional_parameters
    }
}

MENU menu_output
{
    LABEL "Output Configuration";
    ITEMS 
    {  
        menu_current_configuration,
        menu_current_alarms,
        menu_damping_value,
        menu_measure_type,        
        menu_user_loop_test,
        menu_trim_dac
     }
}

/**************************************************************
            MENU OUTPUT
***************************************************************/

MENU menu_damping_value
{
    LABEL "Damping Value";
    ITEMS 
    {  
        PV.DEVICE_VARIABLE.DAMPING_VALUE(DISPLAY_VALUE)
    }
}

METHOD user_loop_test
{
    LABEL [loop_test];
    HELP [loop_test_help];
    DEFINITION
    {
        char status[STATUS_SIZE];
        char disp_string1[60];
        char disp_string2[60];
        long var_id[1];
        int use_abort_method;
        int choice;
        int slen1;
        int slen2;

        slen1 = 60;
        slen2 = 60;

        IGNORE_ALL_RESPONSE_CODES();
        IGNORE_ALL_DEVICE_STATUS();
        XMTR_IGNORE_ALL_DEVICE_STATUS();
        XMTR_IGNORE_ALL_RESPONSE_CODES();

        get_dictionary_string(remove_loop_from_auto, disp_string1, slen1);
        ACKNOWLEDGE(disp_string1);
        add_abort_method(return_to_normal);

        /* 
         * Here comes the standard part for analog outputs, e.g. transmitters 
         */
        use_abort_method = 0;

        do 
        {
            get_dictionary_string(choose_analog_output_level, disp_string1, slen1);
            get_dictionary_string(choices_4_20_other_end, disp_string2, slen2);

            choice = SELECT_FROM_LIST(disp_string1, disp_string2);

            switch (choice)
            {
            case 0:
                assign_float(PV.DAQ.ANALOG_VALUE,4.0);
                break;

            case 1:
                assign_float(PV.DAQ.ANALOG_VALUE,20.0);
                break;

            case 2:
                get_dictionary_string(loop_output, disp_string1, slen1);
                GET_DEV_VAR_VALUE(disp_string1, PV.DAQ.ANALOG_VALUE);
                break;

            case 3:
            default:
                process_abort();
                break;
            }

            send(40, status);

            if (!use_abort_method)
            {
                if ((status[STATUS_RESPONSE_CODE] != 0)
                        && ( status[STATUS_RESPONSE_CODE] != 3)
                        && ( status[STATUS_RESPONSE_CODE] != 4))
                {
                    display_response_status(40,status[STATUS_RESPONSE_CODE]);
                    get_dictionary_string(abort_last_error, disp_string1, slen1);
                    DELAY(2, disp_string1);
                    process_abort();
                }

                if (status[STATUS_RESPONSE_CODE] == 0)
                {
                    remove_abort_method(return_to_normal);
                    add_abort_method(leave_fixed_current_mode);
                    use_abort_method =1;
                }
            }

            if (status[STATUS_RESPONSE_CODE])
            {
                /* 
                 * Display the resonse code from the error 
                 */
                display_response_status(40, status[STATUS_RESPONSE_CODE]);

                /* 
                 * If the response code is either 3 or 4, meaning the value
                 * was either too large or too small, do not abort method.
                 * Allow the user to try again. 
                 */ 
                if ((status[STATUS_RESPONSE_CODE] != 3)
                        && ( status[STATUS_RESPONSE_CODE] != 4))
                {
                    get_dictionary_string(abort_last_error, disp_string1, slen1);
                    DELAY(2, disp_string1);
                    process_abort();
                }
            }
            else
            {
                var_id[0] = VARID(PV.DAQ.ANALOG_VALUE);
                get_dictionary_string(fld_dev_otpt_fixed, disp_string1, slen1);
                acknowledge(disp_string1, var_id);
            }
            } while (choice < 3);
        //ACKNOWLEDGE("Press OK to exit Fixed Current Mode");
        //PV.DAQ.ANALOG_VALUE = 0;
        //send_command(40);
        process_abort();
    }
}

METHOD leave_fixed_current_mode
{
	LABEL [leaving_fixed_current_mode];
	HELP [leaving_fixed_current_mode_help_2];

	DEFINITION
	{
		char status[STATUS_SIZE];
		long var_id[1];
		char disp_string1[60];
		int slen1;

		slen1 =60;

		assign_float(PV.DAQ.ANALOG_VALUE,0.0);
		IGNORE_ALL_RESPONSE_CODES();
		do
		{
			get_dictionary_string(return_fld_dev_to_orig_otpt,disp_string1,slen1);
			DELAY(3,disp_string1);
			send(40,status);
			if ( status[   0] )
			{
				display_response_status(40,status[   0]);
			}
		}
		while ( status[   0]);
		get_dictionary_string(loop_may_be_returned_to_auto,disp_string1,slen1);
		ACKNOWLEDGE(disp_string1);
	}
}

MENU menu_user_loop_test
{
    LABEL "Loop test";
    ITEMS
    {
        user_loop_test
    }
}

MENU menu_trim_dac
{
    LABEL "Trim DAC";
    ITEMS 
    {  
        transmitter_dac_trim        
    }
} 

MENU menu_current_configuration
{
    LABEL "Output configuration";
    ITEMS 
    {  
        alarm_mode,
        namur_mode,
        custom_alarm_current_mode(DISPLAY_VALUE),
        [blank]
    }
}

MENU menu_current_alarms
{
    LABEL "Alarms configuration";
    ITEMS 
    {  
        //hot_start_occure,
        //output_current_fixed,
        //analog_output_saturated,
        ram_error,
        flash_test_error,
        badcrc_in_segment_info,
        ht430_init_error,
        sensor_failure,
        sensor_not_connected,
        primary_variable_not_valid,
        primary_variable_out_of_limits,
        secondary_variable_out_of_limits,
        adc_interface_master_error,
        adc_interface_slave_error,
        adc_not_responded,
        oscillator_fault
    }
}

MENU menu_measure_type
{
    LABEL "Measure type";
    ITEMS 
    {  
        sensorMeasType(DISPLAY_VALUE)
    }
}

/**************************************************************
            MENU INPUT
**************************************************************/

MENU menu_input_type
{
    LABEL "Input Type/Range";
    ITEMS 
    {   
        inputRange(DISPLAY_VALUE),
        temperatureUnits(DISPLAY_VALUE, READ_ONLY),
        sensorType(DISPLAY_VALUE)
    }
} 

//*******************************************************

MENU menu_sensor_connections
{
    LABEL "Sensor Connections and CJC Type";
    ITEMS 
    {  
        sensorConnection(DISPLAY_VALUE),
        cjcType(DISPLAY_VALUE)
    }
}

METHOD  calibrate_zero
{
	LABEL   "Calibrate Zero";
    HELP    "";
    DEFINITION
	{
		char status[STATUS_SIZE];
        
        do
		{
            ACKNOWLEDGE("To perform a calibration you will need precision instruments.");
            ACKNOWLEDGE("Do you really want to continue ?");
            ACKNOWLEDGE("You can restore current calibration by invoking 'Return to factory setting' procedure.");

            assign_float(input_value,0.0);
            GET_DEV_VAR_VALUE("Insert calibrate point", input_value);
			send(202,status);    

			if ( status[STATUS_RESPONSE_CODE] )
			{
				display_response_status(202,status[STATUS_RESPONSE_CODE]);
			}
		}
		while ( status[STATUS_RESPONSE_CODE] );
        
		ACKNOWLEDGE("Calibrate Zero DONE");    }
}

METHOD  calibrate_gain
{
	LABEL   "Calibrate Gain";
    HELP    "";
    DEFINITION
	{
    	char status[STATUS_SIZE];
       
        do
		{
            ACKNOWLEDGE("To perform a calibration you will need precision instruments.");
            ACKNOWLEDGE("Do you really want to continue ?");
            ACKNOWLEDGE("You can restore current calibration by invoking 'Return to factory setting' procedure.");

            assign_float(input_value,0.0);
			GET_DEV_VAR_VALUE("Insert calibrate point", input_value);
			send(203,status);     

			if ( status[STATUS_RESPONSE_CODE] )
			{
				display_response_status(203,status[STATUS_RESPONSE_CODE]);
			}
		}
		while ( status[STATUS_RESPONSE_CODE] );
        
		ACKNOWLEDGE("Calibrate Gain DONE");
    }
}

MENU input_calibration
{
    LABEL "Input Calibration";
    ITEMS 
    {  
        calibrate_zero,
        calibrate_gain
    }
}

MENU additional_parameters
{
    LABEL "Additional Parameters";
    ITEMS 
    {   
        biasChan1(DISPLAY_VALUE),
        biasChan2(DISPLAY_VALUE),
        wireResCompensationChan1(DISPLAY_VALUE),
        wireResCompensationChan2(DISPLAY_VALUE),
        externalCJCValue(DISPLAY_VALUE)
    }
}

MENU process_value
{
    LABEL "Process Value";
    ITEMS 
    {  
        temperatureUSL (DISPLAY_VALUE, READ_ONLY),     
        PV.RANGING.UPPER_RANGE_VALUE(DISPLAY_VALUE),
        menu_span,
        menu_zero,
        PV.RANGING.LOWER_RANGE_VALUE(DISPLAY_VALUE),      
        temperatureLSL (DISPLAY_VALUE, READ_ONLY),                                     
        temperatureMinimumSpan (DISPLAY_VALUE, READ_ONLY),                         
        temperatureUnits(DISPLAY_VALUE)
    }
}

//przycisk SPAN
METHOD menu_span
{
     LABEL "SPAN";
     DEFINITION
    {  
        ACKNOWLEDGE("Press OK to SPAN");
        send_command(36);
    }
} 

//przycisk ZERO
METHOD menu_zero
{
    LABEL "ZERO";
    DEFINITION
    {  
        ACKNOWLEDGE("Press OK to ZERO");
        send_command(37);      
    }
}

MENU current_por
{
    LABEL "PV, Current, percent of range and all charts";
    ITEMS 
    {  
     PV.DEVICE_VARIABLE.DIGITAL_VALUE (DISPLAY_VALUE, READ_ONLY),             // PV
     PV.DAQ.ANALOG_VALUE (DISPLAY_VALUE, READ_ONLY),                          // Current
     PV.RANGING.PERCENT_RANGE (DISPLAY_VALUE, READ_ONLY)                     // percent of range 
    }
}

/************************************************************
                MENU for device_setup
 **************************************************************/

MENU device_setup
{
    STYLE PAGE;
    LABEL [device_setup];
    ITEMS
    { 
        device_menu,
        device_menu_1,
        current_and_4_dynamic,
        device_info,
        write_security,
        reset_device,
        device_error,
        temperaturlimits
    }
} 
/**********************************************************
            Zakadka return to factory settings
***********************************************************/

MENU return_to_factory_settings
{
    STYLE DIALOG;
    LABEL "Return to factory settings";
    ITEMS 
    {  
        return_factory,
        return_to_factory_method
    }
} 

/*********************************************************
            Temperature Limits
**********************************************************/

MENU temperaturlimits
{
    LABEL "Temerature Limits";
    ITEMS
    {
        temperature_UTL(DISPLAY_VALUE),               
        temperature_LTL(DISPLAY_VALUE)
    }
}

/************************************************************
            Reset device
 ************************************************************/

MENU reset_device
{
    LABEL "Reset Device / Configuration Changed Flag";
    ITEMS 
    {   
        device_master_reset,
        reset_device_flag,
        return_to_factory_settings
    }
}

METHOD reset_device_flag
{
    LABEL "Reset Configuration Changed Flag";
    HELP  "";
    DEFINITION 
    {  
        ACKNOWLEDGE("Press OK to Reset Configuration Changed Flag");
        send_command(38);
        
    }
}


MENU current_and_4_dynamic
{
    LABEL "Current and all dynamic variables";
    ITEMS 
    {  
     PV.DAQ.ANALOG_VALUE (DISPLAY_VALUE, READ_ONLY),                 // Current
     PV.DEVICE_VARIABLE.DIGITAL_VALUE (DISPLAY_VALUE),               // PV
     SV.DEVICE_VARIABLE.DIGITAL_VALUE (DISPLAY_VALUE),               // SV
     TV.DEVICE_VARIABLE.DIGITAL_VALUE (DISPLAY_VALUE),               // TV
     QV.DEVICE_VARIABLE.DIGITAL_VALUE (DISPLAY_VALUE)               // QV 
    }
} 

MENU write_security
{
    LABEL "Write protection";
    ITEMS 
    {  
       write_protect(DISPLAY_VALUE),
       toggle_write_protect,
       change_protect_code
    }
}                                                           

METHOD toggle_write_protect
{
    LABEL "Set Write Protect";
    HELP  "";
    DEFINITION 
    {
     assign_int(protect_code,0000);
     GET_DEV_VAR_VALUE( "Type Protect Code", protect_code);
     GET_DEV_VAR_VALUE( "Set Write Protect", write_protect);
     send_command(247);
     //assign_int(protect_code,0000);
    }
}
METHOD change_protect_code
{
    LABEL "Change Protect Code";
    HELP  "";
    DEFINITION 
    {
     assign_int(old_customer_code,0000);
     assign_int(new_customer_code,0000);
     GET_DEV_VAR_VALUE( "Type Old Customer Code", old_customer_code);
     GET_DEV_VAR_VALUE( "Type new Customer Code", new_customer_code);
     //assign_int(old_customer_code,0000);
     //assign_int(new_customer_code,0000);
    }
}

METHOD set_protect
{
    LABEL "Set protect code";
    HELP  "";
    DEFINITION 
    { 
      ACKNOWLEDGE("Press OK to Set Protect Code");
      send_command(247);
    }
}

MENU device_error
{
    LABEL "Error flags";
    ITEMS
    {
        device_specific_status_1, /*error_flags_1*/
        SEPARATOR,
        device_specific_status_0 /*error_flags_2*/
    }
}

MENU device_menu_1
{
    LABEL "Device Identification Part 2";
    ITEMS 
    {
      device_type (DISPLAY_VALUE),
      universal_revision (DISPLAY_VALUE),
      transmitter_revision (DISPLAY_VALUE),
      private_label_distributor (DISPLAY_VALUE),
      temperatureSerialNumber(DISPLAY_VALUE)
    }
} 

MENU device_menu
{
    LABEL "Device Identification Part 1";
    ITEMS 
    {  
        manufacturer_id (DISPLAY_VALUE),
        device_id (DISPLAY_VALUE),
        software_revision (DISPLAY_VALUE),
        hardware_revision (DISPLAY_VALUE),
        request_preambles (DISPLAY_VALUE),
        response_preambles (DISPLAY_VALUE),                                    
        final_assembly_number(DISPLAY_VALUE),
        polling_address(DISPLAY_VALUE),
        device_type (DISPLAY_VALUE),
        universal_revision (DISPLAY_VALUE),
        transmitter_revision (DISPLAY_VALUE),
        private_label_distributor (DISPLAY_VALUE),
        temperatureSerialNumber(DISPLAY_VALUE)
    }
}  

MENU device_info
{
    LABEL [device_information];
    ITEMS
    {
        tag(DISPLAY_VALUE),                         
        descriptor(DISPLAY_VALUE),                 
        message(DISPLAY_VALUE),
        date(DISPLAY_VALUE)  
    }
}

//---------------------- end of file ------------------------------------
      
